@@ -490,6 +490,11 @@ class Server(object):
     @gen.coroutine
     def close(self):
         self.listener.stop()
+        for i in range(20):  # let comms close naturally for a second
+            if not self._comms:
+                break
+            else:
+                yield gen.sleep(0.05)
         for comm in self._comms:
             comm.close()
         for cb in self._ongoing_coroutines:
@@ -593,6 +598,7 @@ class rpc(object):
         self.serializers = serializers
         self.deserializers = deserializers if deserializers is not None else serializers
         self.connection_args = connection_args
+        self._created = weakref.WeakSet()
         rpc.active.add(self)
 
     @gen.coroutine
@@ -632,6 +638,7 @@ class rpc(object):
                 deserialize=self.deserialize,
                 connection_args=self.connection_args,
             )
+            comm.name = "rpc"
         self.comms[comm] = False  # mark as taken
         raise gen.Return(comm)
 
@@ -648,6 +655,9 @@ class rpc(object):
         for comm in list(self.comms):
             if comm and not comm.closed():
                 _close_comm(comm)
+        for comm in list(self._created):
+            if comm and not comm.closed():
+                _close_comm(comm)
         self.comms.clear()
 
     def __getattr__(self, key):
@@ -659,6 +669,7 @@ class rpc(object):
                 kwargs["deserializers"] = self.deserializers
             try:
                 comm = yield self.live_comm()
+                comm.name = "rpc." + key
                 result = yield send_recv(comm=comm, op=key, **kwargs)
             except (RPCClosed, CommClosedError) as e:
                 raise e.__class__(
@@ -723,10 +734,12 @@ class PooledRPCCall(object):
             if self.deserializers is not None and kwargs.get("deserializers") is None:
                 kwargs["deserializers"] = self.deserializers
             comm = yield self.pool.connect(self.addr)
+            name, comm.name = comm.name, "ConnectionPool." + key
             try:
                 result = yield send_recv(comm=comm, op=key, **kwargs)
             finally:
                 self.pool.reuse(self.addr, comm)
+                comm.name = name
 
             raise gen.Return(result)
 
@@ -780,6 +793,8 @@ class ConnectionPool(object):
         Whether or not to deserialize data by default or pass it through
     """
 
+    _instances = weakref.WeakSet()
+
     def __init__(
         self,
         limit=512,
@@ -787,6 +802,8 @@ class ConnectionPool(object):
         serializers=None,
         deserializers=None,
         connection_args=None,
+        timeout=None,
+        server=None,
     ):
         self.limit = limit  # Max number of open comms
         # Invariant: len(available) == open - active
@@ -797,7 +814,11 @@ class ConnectionPool(object):
         self.serializers = serializers
         self.deserializers = deserializers if deserializers is not None else serializers
         self.connection_args = connection_args
+        self.timeout = timeout
         self.event = Event()
+        self.server = weakref.ref(server) if server else None
+        self._created = weakref.WeakSet()
+        self._instances.add(self)
 
     @property
     def active(self):
@@ -838,10 +859,13 @@ class ConnectionPool(object):
         try:
             comm = yield connect(
                 addr,
-                timeout=timeout,
+                timeout=timeout or self.timeout,
                 deserialize=self.deserialize,
                 connection_args=self.connection_args,
             )
+            comm.name = "ConnectionPool"
+            comm._pool = weakref.ref(self)
+            self._created.add(comm)
         except Exception:
             raise
         occupied.add(comm)
@@ -907,6 +931,9 @@ class ConnectionPool(object):
             for comm in comms:
                 comm.abort()
 
+        for comm in self._created:
+            IOLoop.current().add_callback(comm.abort)
+
 
 def coerce_to_address(o):
     if isinstance(o, (list, tuple)):
@@ -959,7 +986,7 @@ def clean_exception(exception, traceback, **kwargs):
     --------
     error_message: create and serialize errors into message
     """
-    if isinstance(exception, bytes):
+    if isinstance(exception, bytes) or isinstance(exception, bytearray):
         try:
             exception = protocol.pickle.loads(exception)
         except Exception:
