@@ -2,7 +2,6 @@ from __future__ import print_function, division, absolute_import
 
 from time import sleep
 
-import pytest
 from toolz import frequencies, pluck
 from tornado import gen
 from tornado.ioloop import IOLoop
@@ -14,21 +13,21 @@ from distributed.metrics import time
 
 
 def test_get_scale_up_kwargs(loop):
-    with LocalCluster(0, scheduler_port=0, silence_logs=False,
-                      dashboard_address=None, loop=loop) as cluster:
+    with LocalCluster(
+        0, scheduler_port=0, silence_logs=False, dashboard_address=None, loop=loop
+    ) as cluster:
 
-        alc = Adaptive(cluster.scheduler, cluster, interval=100,
-                       scale_factor=3)
-        assert alc.get_scale_up_kwargs() == {'n': 1}
+        alc = Adaptive(cluster.scheduler, cluster, interval=100, scale_factor=3)
+        assert alc.get_scale_up_kwargs() == {"n": 1}
 
         with Client(cluster, loop=loop) as c:
             future = c.submit(lambda x: x + 1, 1)
             assert future.result() == 2
             assert c.ncores()
-            assert alc.get_scale_up_kwargs() == {'n': 3}
+            assert alc.get_scale_up_kwargs() == {"n": 3}
 
 
-@gen_cluster(client=True, ncores=[('127.0.0.1', 1)] * 4)
+@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 4)
 def test_simultaneous_scale_up_and_down(c, s, *workers):
     class TestAdaptive(Adaptive):
         def get_scale_up_kwargs(self):
@@ -46,11 +45,11 @@ def test_simultaneous_scale_up_and_down(c, s, *workers):
 
     cluster = TestCluster()
 
-    s.task_duration['a'] = 4
-    s.task_duration['b'] = 4
-    s.task_duration['c'] = 1
+    s.task_duration["a"] = 4
+    s.task_duration["b"] = 4
+    s.task_duration["c"] = 1
 
-    future = c.map(slowinc, [1, 1, 1], key=['a-4', 'b-4', 'c-1'])
+    future = c.map(slowinc, [1, 1, 1], key=["a-4", "b-4", "c-1"])
 
     while len(s.rprocessing) < 3:
         yield gen.sleep(0.001)
@@ -61,8 +60,9 @@ def test_simultaneous_scale_up_and_down(c, s, *workers):
 
 
 def test_adaptive_local_cluster(loop):
-    with LocalCluster(0, scheduler_port=0, silence_logs=False,
-                      dashboard_address=None, loop=loop) as cluster:
+    with LocalCluster(
+        0, scheduler_port=0, silence_logs=False, dashboard_address=None, loop=loop
+    ) as cluster:
         alc = Adaptive(cluster.scheduler, cluster, interval=100)
         with Client(cluster, loop=loop) as c:
             assert not c.ncores()
@@ -86,9 +86,14 @@ def test_adaptive_local_cluster(loop):
 @nodebug
 @gen_test(timeout=30)
 def test_adaptive_local_cluster_multi_workers():
-    cluster = yield LocalCluster(0, scheduler_port=0, silence_logs=False,
-                                 processes=False, dashboard_address=None,
-                                 asynchronous=True)
+    cluster = yield LocalCluster(
+        0,
+        scheduler_port=0,
+        silence_logs=False,
+        processes=False,
+        dashboard_address=None,
+        asynchronous=True,
+    )
     try:
         cluster.scheduler.allowed_failures = 1000
         alc = cluster.adapt(interval=100)
@@ -124,7 +129,7 @@ def test_adaptive_local_cluster_multi_workers():
         yield cluster.close()
 
 
-@gen_cluster(client=True, ncores=[('127.0.0.1', 1)] * 10, active_rpc_timeout=10)
+@gen_cluster(client=True, ncores=[("127.0.0.1", 1)] * 10, active_rpc_timeout=10)
 def test_adaptive_scale_down_override(c, s, *workers):
     class TestAdaptive(Adaptive):
         def __init__(self, *args, **kwargs):
@@ -135,7 +140,7 @@ def test_adaptive_scale_down_override(c, s, *workers):
             num_workers = len(self.scheduler.workers)
             to_close = self.scheduler.workers_to_close(**kwargs)
             if num_workers - len(to_close) < self.min_size:
-                to_close = to_close[:num_workers - self.min_size]
+                to_close = to_close[: num_workers - self.min_size]
 
             return to_close
 
@@ -151,7 +156,7 @@ def test_adaptive_scale_down_override(c, s, *workers):
     # Assert that adaptive cycle does not reduce cluster below minimum size
     # as determined via override.
     cluster = TestCluster()
-    ta = TestAdaptive(s, cluster, min_size=2, interval=.1, scale_factor=2)
+    ta = TestAdaptive(s, cluster, min_size=2, interval=0.1, scale_factor=2)
     yield gen.sleep(0.3)
 
     assert len(s.workers) == 2
@@ -160,13 +165,25 @@ def test_adaptive_scale_down_override(c, s, *workers):
 @gen_test(timeout=30)
 def test_min_max():
     loop = IOLoop.current()
-    cluster = yield LocalCluster(0, scheduler_port=0, silence_logs=False,
-                                 processes=False, dashboard_address=None,
-                                 loop=loop, asynchronous=True)
+    cluster = yield LocalCluster(
+        0,
+        scheduler_port=0,
+        silence_logs=False,
+        processes=False,
+        dashboard_address=None,
+        loop=loop,
+        asynchronous=True,
+    )
     yield cluster._start()
     try:
-        adapt = Adaptive(cluster.scheduler, cluster, minimum=1, maximum=2,
-                         interval='20 ms', wait_count=10)
+        adapt = Adaptive(
+            cluster.scheduler,
+            cluster,
+            minimum=1,
+            maximum=2,
+            interval="20 ms",
+            wait_count=10,
+        )
         c = yield Client(cluster, asynchronous=True, loop=loop)
 
         start = time()
@@ -176,7 +193,7 @@ def test_min_max():
 
         yield gen.sleep(0.2)
         assert len(cluster.scheduler.workers) == 1
-        assert frequencies(pluck(1, adapt.log)) == {'up': 1}
+        assert frequencies(pluck(1, adapt.log)) == {"up": 1}
 
         futures = c.map(slowinc, range(100), delay=0.1)
 
@@ -189,7 +206,7 @@ def test_min_max():
         yield gen.sleep(0.5)
         assert len(cluster.scheduler.workers) == 2
         assert len(cluster.workers) == 2
-        assert frequencies(pluck(1, adapt.log)) == {'up': 2}
+        assert frequencies(pluck(1, adapt.log)) == {"up": 2}
 
         del futures
 
@@ -197,7 +214,7 @@ def test_min_max():
         while len(cluster.scheduler.workers) != 1:
             yield gen.sleep(0.01)
             assert time() < start + 2
-        assert frequencies(pluck(1, adapt.log)) == {'up': 2, 'down': 1}
+        assert frequencies(pluck(1, adapt.log)) == {"up": 2, "down": 1}
     finally:
         yield c.close()
         yield cluster.close()
@@ -210,18 +227,23 @@ def test_avoid_churn():
     Instead we want to wait a few beats before removing a worker in case the
     user is taking a brief pause between work
     """
-    cluster = yield LocalCluster(0, asynchronous=True, processes=False,
-                                 scheduler_port=0, silence_logs=False,
-                                 dashboard_address=None)
+    cluster = yield LocalCluster(
+        0,
+        asynchronous=True,
+        processes=False,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    )
     client = yield Client(cluster, asynchronous=True)
     try:
-        adapt = Adaptive(cluster.scheduler, cluster, interval='20 ms', wait_count=5)
+        adapt = Adaptive(cluster.scheduler, cluster, interval="20 ms", wait_count=5)
 
         for i in range(10):
             yield client.submit(slowinc, i, delay=0.040)
             yield gen.sleep(0.040)
 
-        assert frequencies(pluck(1, adapt.log)) == {'up': 1}
+        assert frequencies(pluck(1, adapt.log)) == {"up": 1}
     finally:
         yield client.close()
         yield cluster.close()
@@ -234,12 +256,16 @@ def test_adapt_quickly():
     Instead we want to wait a few beats before removing a worker in case the
     user is taking a brief pause between work
     """
-    cluster = yield LocalCluster(0, asynchronous=True, processes=False,
-                                 scheduler_port=0, silence_logs=False,
-                                 dashboard_address=None)
+    cluster = yield LocalCluster(
+        0,
+        asynchronous=True,
+        processes=False,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    )
     client = yield Client(cluster, asynchronous=True)
-    adapt = Adaptive(cluster.scheduler, cluster, interval=20, wait_count=5,
-                     maximum=10)
+    adapt = Adaptive(cluster.scheduler, cluster, interval=20, wait_count=5, maximum=10)
     try:
         future = client.submit(slowinc, 1, delay=0.100)
         yield wait(future)
@@ -247,12 +273,12 @@ def test_adapt_quickly():
 
         # Scale up when there is plenty of available work
         futures = client.map(slowinc, range(1000), delay=0.100)
-        while frequencies(pluck(1, adapt.log)) == {'up': 1}:
+        while frequencies(pluck(1, adapt.log)) == {"up": 1}:
             yield gen.sleep(0.01)
         assert len(adapt.log) == 2
-        assert 'up' in adapt.log[-1]
+        assert "up" in adapt.log[-1]
         d = [x for x in adapt.log[-1] if isinstance(x, dict)][0]
-        assert 2 < d['n'] <= adapt.maximum
+        assert 2 < d["n"] <= adapt.maximum
 
         while len(cluster.scheduler.workers) < adapt.maximum:
             yield gen.sleep(0.01)
@@ -277,11 +303,16 @@ def test_adapt_quickly():
 @gen_test(timeout=None)
 def test_adapt_down():
     """ Ensure that redefining adapt with a lower maximum removes workers """
-    cluster = yield LocalCluster(0, asynchronous=True, processes=False,
-                                 scheduler_port=0, silence_logs=False,
-                                 dashboard_address=None)
+    cluster = yield LocalCluster(
+        0,
+        asynchronous=True,
+        processes=False,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    )
     client = yield Client(cluster, asynchronous=True)
-    cluster.adapt(interval='20ms', maximum=5)
+    cluster.adapt(interval="20ms", maximum=5)
 
     try:
         futures = client.map(slowinc, range(1000), delay=0.1)
@@ -299,19 +330,25 @@ def test_adapt_down():
         yield cluster.close()
 
 
-@pytest.mark.xfail(reason="we currently only judge occupancy, not ntasks")
 @gen_test(timeout=30)
 def test_no_more_workers_than_tasks():
     loop = IOLoop.current()
-    cluster = yield LocalCluster(0, scheduler_port=0, silence_logs=False,
-                                 processes=False, dashboard_address=None,
-                                 loop=loop, asynchronous=True)
+    cluster = yield LocalCluster(
+        0,
+        scheduler_port=0,
+        silence_logs=False,
+        processes=False,
+        dashboard_address=None,
+        loop=loop,
+        asynchronous=True,
+    )
     yield cluster._start()
     try:
-        adapt = Adaptive(cluster.scheduler, cluster, minimum=0, maximum=4,
-                         interval='10 ms')
+        adapt = Adaptive(
+            cluster.scheduler, cluster, minimum=0, maximum=4, interval="10 ms"
+        )
         client = yield Client(cluster, asynchronous=True, loop=loop)
-        cluster.scheduler.task_duration['slowinc'] = 1000
+        cluster.scheduler.task_duration["slowinc"] = 1000
 
         yield client.submit(slowinc, 1, delay=0.100)
 
@@ -323,8 +360,9 @@ def test_no_more_workers_than_tasks():
 
 def test_basic_no_loop():
     try:
-        with LocalCluster(0, scheduler_port=0, silence_logs=False,
-                          dashboard_address=None) as cluster:
+        with LocalCluster(
+            0, scheduler_port=0, silence_logs=False, dashboard_address=None
+        ) as cluster:
             with Client(cluster) as client:
                 cluster.adapt()
                 future = client.submit(lambda x: x + 1, 1)
@@ -337,13 +375,18 @@ def test_basic_no_loop():
 @gen_test(timeout=None)
 def test_target_duration():
     """ Ensure that redefining adapt with a lower maximum removes workers """
-    cluster = yield LocalCluster(0, asynchronous=True, processes=False,
-                                 scheduler_port=0, silence_logs=False,
-                                 dashboard_address=None)
+    cluster = yield LocalCluster(
+        0,
+        asynchronous=True,
+        processes=False,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    )
     client = yield Client(cluster, asynchronous=True)
-    adaptive = cluster.adapt(interval='20ms', minimum=2, target_duration='5s')
+    adaptive = cluster.adapt(interval="20ms", minimum=2, target_duration="5s")
 
-    cluster.scheduler.task_duration['slowinc'] = 1
+    cluster.scheduler.task_duration["slowinc"] = 1
 
     try:
         while len(cluster.scheduler.workers) < 2:
@@ -354,8 +397,8 @@ def test_target_duration():
         while len(adaptive.log) < 2:
             yield gen.sleep(0.01)
 
-        assert adaptive.log[0][1:] == ('up', {'n': 2})
-        assert adaptive.log[1][1:] == ('up', {'n': 20})
+        assert adaptive.log[0][1:] == ("up", {"n": 2})
+        assert adaptive.log[1][1:] == ("up", {"n": 20})
 
     finally:
         yield client.close()
@@ -365,22 +408,30 @@ def test_target_duration():
 @gen_test(timeout=None)
 def test_worker_keys():
     """ Ensure that redefining adapt with a lower maximum removes workers """
-    cluster = yield LocalCluster(0, asynchronous=True, processes=False,
-                                 scheduler_port=0, silence_logs=False,
-                                 dashboard_address=None)
+    cluster = yield LocalCluster(
+        0,
+        asynchronous=True,
+        processes=False,
+        scheduler_port=0,
+        silence_logs=False,
+        dashboard_address=None,
+    )
 
     try:
-        yield [cluster.start_worker(name='a-1'),
-               cluster.start_worker(name='a-2'),
-               cluster.start_worker(name='b-1'),
-               cluster.start_worker(name='b-2')]
+        yield [
+            cluster.start_worker(name="a-1"),
+            cluster.start_worker(name="a-2"),
+            cluster.start_worker(name="b-1"),
+            cluster.start_worker(name="b-2"),
+        ]
 
         while len(cluster.scheduler.workers) != 4:
             yield gen.sleep(0.01)
 
         def key(ws):
-            return ws.name.split('-')[0]
-        cluster._adaptive_options = {'worker_key': key}
+            return ws.name.split("-")[0]
+
+        cluster._adaptive_options = {"worker_key": key}
 
         adaptive = cluster.adapt(minimum=1)
         yield adaptive._adapt()
@@ -389,7 +440,7 @@ def test_worker_keys():
             yield gen.sleep(0.01)
 
         names = {ws.name for ws in cluster.scheduler.workers.values()}
-        assert names == {'a-1', 'a-2'} or names == {'b-1', 'b-2'}
+        assert names == {"a-1", "a-2"} or names == {"b-1", "b-2"}
     finally:
         yield cluster.close()
 
@@ -403,4 +454,4 @@ def test_without_cluster(c, s):
         yield gen.sleep(0.01)
 
     response = yield c.scheduler.adaptive_recommendations()
-    assert response['status'] == 'up'
+    assert response["status"] == "up"
