@@ -13,8 +13,9 @@ from toolz import identity, partial
 
 try:
     import blosc
+
     n = blosc.set_nthreads(2)
-    if hasattr('blosc', 'releasegil'):
+    if hasattr("blosc", "releasegil"):
         blosc.set_releasegil(True)
 except ImportError:
     blosc = False
@@ -22,8 +23,7 @@ except ImportError:
 from ..utils import ignoring, ensure_bytes
 
 
-compressions = {None: {'compress': identity,
-                       'decompress': identity}}
+compressions = {None: {"compress": identity, "decompress": identity}}
 
 compressions[False] = compressions[None]  # alias
 
@@ -36,8 +36,8 @@ logger = logging.getLogger(__name__)
 
 with ignoring(ImportError):
     import zlib
-    compressions['zlib'] = {'compress': zlib.compress,
-                            'decompress': zlib.decompress}
+
+    compressions["zlib"] = {"compress": zlib.compress, "decompress": zlib.decompress}
 
 with ignoring(ImportError):
     import snappy
@@ -48,9 +48,11 @@ with ignoring(ImportError):
             data = bytes(data)
         return snappy.decompress(data)
 
-    compressions['snappy'] = {'compress': snappy.compress,
-                              'decompress': _fixed_snappy_decompress}
-    default_compression = 'snappy'
+    compressions["snappy"] = {
+        "compress": snappy.compress,
+        "decompress": _fixed_snappy_decompress,
+    }
+    default_compression = "snappy"
 
 with ignoring(ImportError):
     import lz4
@@ -58,6 +60,7 @@ with ignoring(ImportError):
     try:
         # try using the new lz4 API
         import lz4.block
+
         lz4_compress = lz4.block.compress
         lz4_decompress = lz4.block.decompress
     except ImportError:
@@ -86,25 +89,31 @@ with ignoring(ImportError):
             else:
                 raise
 
-    compressions['lz4'] = {'compress': _fixed_lz4_compress,
-                           'decompress': _fixed_lz4_decompress}
-    default_compression = 'lz4'
+    compressions["lz4"] = {
+        "compress": _fixed_lz4_compress,
+        "decompress": _fixed_lz4_decompress,
+    }
+    default_compression = "lz4"
 
 with ignoring(ImportError):
     import blosc
-    compressions['blosc'] = {'compress': partial(blosc.compress, clevel=5,
-                                                 cname='lz4'),
-                             'decompress': blosc.decompress}
+
+    compressions["blosc"] = {
+        "compress": partial(blosc.compress, clevel=5, cname="lz4"),
+        "decompress": blosc.decompress,
+    }
 
 
-default = dask.config.get('distributed.comm.compression')
-if default != 'auto':
+default = dask.config.get("distributed.comm.compression")
+if default != "auto":
     if default in compressions:
         default_compression = default
     else:
-        raise ValueError("Default compression '%s' not found.\n"
-                         "Choices include auto, %s" % (
-                             default, ', '.join(sorted(map(str, compressions)))))
+        raise ValueError(
+            "Default compression '%s' not found.\n"
+            "Choices include auto, %s"
+            % (default, ", ".join(sorted(map(str, compressions))))
+        )
 
 
 def byte_sample(b, size, n):
@@ -125,7 +134,7 @@ def byte_sample(b, size, n):
     ends.append(starts[-1] + size)
 
     parts = [b[start:end] for start, end in zip(starts, ends)]
-    return b''.join(map(ensure_bytes, parts))
+    return b"".join(map(ensure_bytes, parts))
 
 
 def maybe_compress(payload, min_size=1e4, sample_size=1e4, nsamples=5):
@@ -139,21 +148,21 @@ def maybe_compress(payload, min_size=1e4, sample_size=1e4, nsamples=5):
         return the original
     4.  We return the compressed result
     """
-    compression = dask.config.get('distributed.comm.compression')
-    if compression == 'auto':
+    compression = dask.config.get("distributed.comm.compression")
+    if compression == "auto":
         compression = default_compression
 
     if not compression:
         return None, payload
     if len(payload) < min_size:
         return None, payload
-    if len(payload) > 2**31:  # Too large, compression libraries often fail
+    if len(payload) > 2 ** 31:  # Too large, compression libraries often fail
         return None, payload
 
     min_size = int(min_size)
     sample_size = int(sample_size)
 
-    compress = compressions[compression]['compress']
+    compress = compressions[compression]["compress"]
 
     # Compress a sample, return original if not very compressed
     sample = byte_sample(payload, sample_size, nsamples)
@@ -167,9 +176,10 @@ def maybe_compress(payload, min_size=1e4, sample_size=1e4, nsamples=5):
 
     if default_compression and blosc and type(payload) is memoryview:
         # Blosc does itemsize-aware shuffling, resulting in better compression
-        compressed = blosc.compress(payload, typesize=payload.itemsize,
-                                    cname='lz4', clevel=5)
-        compression = 'blosc'
+        compressed = blosc.compress(
+            payload, typesize=payload.itemsize, cname="lz4", clevel=5
+        )
+        compression = "blosc"
     else:
         compressed = compress(ensure_bytes(payload))
 
@@ -181,5 +191,7 @@ def maybe_compress(payload, min_size=1e4, sample_size=1e4, nsamples=5):
 
 def decompress(header, frames):
     """ Decompress frames according to information in the header """
-    return [compressions[c]['decompress'](frame)
-            for c, frame in zip(header['compression'], frames)]
+    return [
+        compressions[c]["decompress"](frame)
+        for c, frame in zip(header["compression"], frames)
+    ]
