@@ -1,15 +1,15 @@
 from distributed.protocol import serialize, deserialize
 import pytest
 
-np = pytest.importorskip('numpy')
-torch = pytest.importorskip('torch')
+np = pytest.importorskip("numpy")
+torch = pytest.importorskip("torch")
 
 
 def test_tensor():
     x = np.arange(10)
     t = torch.Tensor(x)
     header, frames = serialize(t)
-    assert header['serializer'] == 'dask'
+    assert header["serializer"] == "dask"
     t2 = deserialize(header, frames)
     assert (x == t2.numpy()).all()
 
@@ -25,7 +25,7 @@ def test_grad():
 
 
 def test_resnet():
-    torchvision = pytest.importorskip('torchvision')
+    torchvision = pytest.importorskip("torchvision")
     model = torchvision.models.resnet.resnet18()
 
     header, frames = serialize(model)
