@@ -15,6 +15,5 @@ def safe_sizeof(obj, default_size=1e6):
     try:
         return sizeof(obj)
     except Exception:
-        logger.warning('Sizeof calculation failed.  Defaulting to 1MB',
-                       exc_info=True)
+        logger.warning("Sizeof calculation failed.  Defaulting to 1MB", exc_info=True)
         return int(default_size)
