@@ -60,7 +60,7 @@ def test_as_completed_async_for_results(c, s, a, b):
     yield f()
 
     assert set(results) == set(range(1, 11))
-    assert not s.counters['op'].components[0]['gather']
+    assert not s.counters["op"].components[0]["gather"]
 
 
 @gen_cluster(client=True)
@@ -102,16 +102,16 @@ def test_async_with(loop):
     loop.run_sync(f)
 
     assert result == 11
-    assert client.status == 'closed'
-    assert cluster.status == 'closed'
+    assert client.status == "closed"
+    assert cluster.status == "closed"
 
 
 def test_locks(loop):
     async def f():
         async with Client(processes=False, asynchronous=True) as c:
             assert c.asynchronous
-            async with Lock('x'):
-                lock2 = Lock('x')
+            async with Lock("x"):
+                lock2 = Lock("x")
                 result = await lock2.acquire(timeout=0.1)
                 assert result is False
 
@@ -124,7 +124,7 @@ def test_client_sync_with_async_def(loop):
         return 1
 
     with cluster() as (s, [a, b]):
-        with Client(s['address'], loop=loop) as c:
+        with Client(s["address"], loop=loop) as c:
             assert sync(loop, ff) == 1
             assert c.sync(ff) == 1
 
@@ -132,8 +132,8 @@ def test_client_sync_with_async_def(loop):
 @pytest.mark.xfail(reason="known intermittent failure")
 @gen_cluster(client=True)
 async def test_dont_hold_on_to_large_messages(c, s, a, b):
-    np = pytest.importorskip('numpy')
-    da = pytest.importorskip('dask.array')
+    np = pytest.importorskip("numpy")
+    da = pytest.importorskip("dask.array")
     x = np.random.random(1000000)
     xr = weakref.ref(x)
 
@@ -146,6 +146,7 @@ async def test_dont_hold_on_to_large_messages(c, s, a, b):
         if time() > start + 5:
             # Help diagnosing
             from types import FrameType
+
             x = xr()
             if x is not None:
                 del x
@@ -154,8 +155,12 @@ async def test_dont_hold_on_to_large_messages(c, s, a, b):
                 print("refs to x:", rc, refs, gc.isenabled())
                 frames = [r for r in refs if isinstance(r, FrameType)]
                 for i, f in enumerate(frames):
-                    print("frames #%d:" % i,
-                          f.f_code.co_name, f.f_code.co_filename, sorted(f.f_locals))
+                    print(
+                        "frames #%d:" % i,
+                        f.f_code.co_name,
+                        f.f_code.co_filename,
+                        sorted(f.f_locals),
+                    )
             pytest.fail("array should have been destroyed")
 
         await gen.sleep(0.200)
@@ -165,41 +170,41 @@ async def test_dont_hold_on_to_large_messages(c, s, a, b):
 async def test_run_scheduler_async_def(c, s, a, b):
     async def f(dask_scheduler):
         await gen.sleep(0.01)
-        dask_scheduler.foo = 'bar'
+        dask_scheduler.foo = "bar"
 
     await c.run_on_scheduler(f)
 
-    assert s.foo == 'bar'
+    assert s.foo == "bar"
 
     async def f(dask_worker):
         await gen.sleep(0.01)
-        dask_worker.foo = 'bar'
+        dask_worker.foo = "bar"
 
     await c.run(f)
-    assert a.foo == 'bar'
-    assert b.foo == 'bar'
+    assert a.foo == "bar"
+    assert b.foo == "bar"
 
 
 @gen_cluster(client=True)
 async def test_run_scheduler_async_def_wait(c, s, a, b):
     async def f(dask_scheduler):
         await gen.sleep(0.01)
-        dask_scheduler.foo = 'bar'
+        dask_scheduler.foo = "bar"
 
     await c.run_on_scheduler(f, wait=False)
 
-    while not hasattr(s, 'foo'):
+    while not hasattr(s, "foo"):
         await gen.sleep(0.01)
-    assert s.foo == 'bar'
+    assert s.foo == "bar"
 
     async def f(dask_worker):
         await gen.sleep(0.01)
-        dask_worker.foo = 'bar'
+        dask_worker.foo = "bar"
 
     await c.run(f, wait=False)
 
-    while not hasattr(a, 'foo') or not hasattr(b, 'foo'):
+    while not hasattr(a, "foo") or not hasattr(b, "foo"):
         await gen.sleep(0.01)
 
-    assert a.foo == 'bar'
-    assert b.foo == 'bar'
+    assert a.foo == "bar"
+    assert b.foo == "bar"
