@@ -11,11 +11,17 @@ except ImportError:
     Digest = None
 
 
-@pytest.mark.parametrize('CD,size', [
-    (Counter, lambda d: sum(d.values())),
-    pytest.param(Digest, lambda x: x.size(),
-                 marks=pytest.mark.skipif(not Digest, reason="no crick library"))
-])
+@pytest.mark.parametrize(
+    "CD,size",
+    [
+        (Counter, lambda d: sum(d.values())),
+        pytest.param(
+            Digest,
+            lambda x: x.size(),
+            marks=pytest.mark.skipif(not Digest, reason="no crick library"),
+        ),
+    ],
+)
 def test_digest(loop, CD, size):
     c = CD(loop=loop)
     c.add(1)
