@@ -9,20 +9,30 @@ import sys
 from time import sleep
 
 import mock
+import pytest
 
-from distributed.compatibility import Empty
+import dask
+from distributed.compatibility import Empty, WINDOWS
 from distributed.diskutils import WorkSpace
 from distributed.metrics import time
 from distributed.utils import mp_context
-from distributed.utils_test import captured_logger, slow, new_config
+from distributed.utils_test import captured_logger, slow
 
 
-def assert_directory_contents(dir_path, expected):
+def assert_directory_contents(dir_path, expected, trials=2):
     expected = [os.path.join(dir_path, p) for p in expected]
-    actual = [os.path.join(dir_path, p)
-              for p in os.listdir(dir_path)
-              if p not in ('global.lock', 'purge.lock')]
-    assert sorted(actual) == sorted(expected)
+    for i in range(trials):
+        actual = [
+            os.path.join(dir_path, p)
+            for p in os.listdir(dir_path)
+            if p not in ("global.lock", "purge.lock")
+        ]
+        if sorted(actual) == sorted(expected):
+            break
+        else:
+            sleep(0.5)
+    else:
+        assert sorted(actual) == sorted(expected)
 
 
 def test_workdir_simple(tmpdir):
@@ -32,29 +42,29 @@ def test_workdir_simple(tmpdir):
 
     ws = WorkSpace(base_dir)
     assert_contents([])
-    a = ws.new_work_dir(name='aa')
-    assert_contents(['aa', 'aa.dirlock'])
-    b = ws.new_work_dir(name='bb')
-    assert_contents(['aa', 'aa.dirlock', 'bb', 'bb.dirlock'])
+    a = ws.new_work_dir(name="aa")
+    assert_contents(["aa", "aa.dirlock"])
+    b = ws.new_work_dir(name="bb")
+    assert_contents(["aa", "aa.dirlock", "bb", "bb.dirlock"])
     ws._purge_leftovers()
-    assert_contents(['aa', 'aa.dirlock', 'bb', 'bb.dirlock'])
+    assert_contents(["aa", "aa.dirlock", "bb", "bb.dirlock"])
 
     a.release()
-    assert_contents(['bb', 'bb.dirlock'])
+    assert_contents(["bb", "bb.dirlock"])
     del b
     gc.collect()
     assert_contents([])
 
     # Generated temporary name with a prefix
-    a = ws.new_work_dir(prefix='foo-')
-    b = ws.new_work_dir(prefix='bar-')
-    c = ws.new_work_dir(prefix='bar-')
-    assert_contents({a.dir_path, a._lock_path,
-                     b.dir_path, b._lock_path,
-                     c.dir_path, c._lock_path})
-    assert os.path.basename(a.dir_path).startswith('foo-')
-    assert os.path.basename(b.dir_path).startswith('bar-')
-    assert os.path.basename(c.dir_path).startswith('bar-')
+    a = ws.new_work_dir(prefix="foo-")
+    b = ws.new_work_dir(prefix="bar-")
+    c = ws.new_work_dir(prefix="bar-")
+    assert_contents(
+        {a.dir_path, a._lock_path, b.dir_path, b._lock_path, c.dir_path, c._lock_path}
+    )
+    assert os.path.basename(a.dir_path).startswith("foo-")
+    assert os.path.basename(b.dir_path).startswith("bar-")
+    assert os.path.basename(c.dir_path).startswith("bar-")
     assert b.dir_path != c.dir_path
 
 
@@ -66,22 +76,22 @@ def test_two_workspaces_in_same_directory(tmpdir):
 
     ws = WorkSpace(base_dir)
     assert_contents([])
-    a = ws.new_work_dir(name='aa')
-    assert_contents(['aa', 'aa.dirlock'])
+    a = ws.new_work_dir(name="aa")
+    assert_contents(["aa", "aa.dirlock"])
 
     ws2 = WorkSpace(base_dir)
     ws2._purge_leftovers()
-    assert_contents(['aa', 'aa.dirlock'])
-    b = ws.new_work_dir(name='bb')
-    assert_contents(['aa', 'aa.dirlock', 'bb', 'bb.dirlock'])
+    assert_contents(["aa", "aa.dirlock"])
+    b = ws.new_work_dir(name="bb")
+    assert_contents(["aa", "aa.dirlock", "bb", "bb.dirlock"])
 
     del ws
     del b
     gc.collect()
-    assert_contents(['aa', 'aa.dirlock'])
+    assert_contents(["aa", "aa.dirlock"], trials=5)
     del a
     gc.collect()
-    assert_contents([])
+    assert_contents([], trials=5)
 
 
 def test_workspace_process_crash(tmpdir):
@@ -106,26 +116,31 @@ def test_workspace_process_crash(tmpdir):
         sys.stdout.flush()
 
         time.sleep(100)
-        """ % dict(base_dir=base_dir)
+        """ % dict(
+        base_dir=base_dir
+    )
 
-    p = subprocess.Popen([sys.executable, '-c', code],
-                         stdin=subprocess.PIPE, stdout=subprocess.PIPE,
-                         universal_newlines=True)
+    p = subprocess.Popen(
+        [sys.executable, "-c", code],
+        stdin=subprocess.PIPE,
+        stdout=subprocess.PIPE,
+        universal_newlines=True,
+    )
     line = p.stdout.readline()
     assert p.poll() is None
     a_path, b_path = eval(line)
-    assert_contents([a_path, a_path + '.dirlock', b_path, b_path + '.dirlock'])
+    assert_contents([a_path, a_path + ".dirlock", b_path, b_path + ".dirlock"])
 
     # The child process holds a lock so the work dirs shouldn't be removed
     ws._purge_leftovers()
-    assert_contents([a_path, a_path + '.dirlock', b_path, b_path + '.dirlock'])
+    assert_contents([a_path, a_path + ".dirlock", b_path, b_path + ".dirlock"])
 
     # Kill the process so it's unable to clear the work dirs itself
     p.kill()
     assert p.wait()  # process returned with non-zero code
-    assert_contents([a_path, a_path + '.dirlock', b_path, b_path + '.dirlock'])
+    assert_contents([a_path, a_path + ".dirlock", b_path, b_path + ".dirlock"])
 
-    with captured_logger('distributed.diskutils', 'INFO', propagate=False) as sio:
+    with captured_logger("distributed.diskutils", "INFO", propagate=False) as sio:
         ws._purge_leftovers()
     assert_contents([])
     # One log line per purged directory
@@ -139,9 +154,9 @@ def test_workspace_rmtree_failure(tmpdir):
     base_dir = str(tmpdir)
 
     ws = WorkSpace(base_dir)
-    a = ws.new_work_dir(name='aa')
+    a = ws.new_work_dir(name="aa")
     shutil.rmtree(a.dir_path)
-    with captured_logger('distributed.diskutils', 'ERROR', propagate=False) as sio:
+    with captured_logger("distributed.diskutils", "ERROR", propagate=False) as sio:
         a.release()
     lines = sio.getvalue().splitlines()
     # shutil.rmtree() may call its onerror callback several times
@@ -153,21 +168,21 @@ def test_workspace_rmtree_failure(tmpdir):
 def test_locking_disabled(tmpdir):
     base_dir = str(tmpdir)
 
-    with new_config({'use-file-locking': False}):
-        with mock.patch('distributed.diskutils.locket.lock_file') as lock_file:
+    with dask.config.set({"distributed.worker.use-file-locking": False}):
+        with mock.patch("distributed.diskutils.locket.lock_file") as lock_file:
             assert_contents = functools.partial(assert_directory_contents, base_dir)
 
             ws = WorkSpace(base_dir)
             assert_contents([])
-            a = ws.new_work_dir(name='aa')
-            assert_contents(['aa'])
-            b = ws.new_work_dir(name='bb')
-            assert_contents(['aa', 'bb'])
+            a = ws.new_work_dir(name="aa")
+            assert_contents(["aa"])
+            b = ws.new_work_dir(name="bb")
+            assert_contents(["aa", "bb"])
             ws._purge_leftovers()
-            assert_contents(['aa', 'bb'])
+            assert_contents(["aa", "bb"])
 
             a.release()
-            assert_contents(['bb'])
+            assert_contents(["bb"])
             del b
             gc.collect()
             assert_contents([])
@@ -178,7 +193,7 @@ def test_locking_disabled(tmpdir):
 def _workspace_concurrency(base_dir, purged_q, err_q, stop_evt):
     ws = WorkSpace(base_dir)
     n_purged = 0
-    with captured_logger('distributed.diskutils', 'ERROR') as sio:
+    with captured_logger("distributed.diskutils", "ERROR") as sio:
         while not stop_evt.is_set():
             # Add a bunch of locks, and simulate forgetting them
             try:
@@ -191,7 +206,7 @@ def _workspace_concurrency(base_dir, purged_q, err_q, stop_evt):
     lines = sio.getvalue().splitlines()
     if lines:
         try:
-            raise AssertionError("got %d logs, see stderr" % (len(lines,)))
+            raise AssertionError("got %d logs, see stderr" % (len(lines)))
         except Exception as e:
             err_q.put(e)
 
@@ -213,10 +228,13 @@ def _test_workspace_concurrency(tmpdir, timeout, max_procs):
     ws._purge_leftovers = lambda: None
 
     # Run a bunch of child processes that will try to purge concurrently
-    NPROCS = 2 if sys.platform == 'win32' else max_procs
-    processes = [mp_context.Process(target=_workspace_concurrency,
-                                    args=(base_dir, purged_q, err_q, stop_evt))
-                 for i in range(NPROCS)]
+    NPROCS = 2 if sys.platform == "win32" else max_procs
+    processes = [
+        mp_context.Process(
+            target=_workspace_concurrency, args=(base_dir, purged_q, err_q, stop_evt)
+        )
+        for i in range(NPROCS)
+    ]
     for p in processes:
         p.start()
 
@@ -228,7 +246,7 @@ def _test_workspace_concurrency(tmpdir, timeout, max_procs):
             # Add a bunch of locks, and simulate forgetting them.
             # The concurrent processes should try to purge them.
             for i in range(50):
-                d = ws.new_work_dir(prefix='workspace-concurrency-')
+                d = ws.new_work_dir(prefix="workspace-concurrency-")
                 d._finalizer.detach()
                 n_created += 1
             sleep(1e-2)
@@ -256,6 +274,8 @@ def _test_workspace_concurrency(tmpdir, timeout, max_procs):
 
 
 def test_workspace_concurrency(tmpdir):
+    if WINDOWS:
+        raise pytest.xfail.Exception("TODO: unknown failure on windows")
     _test_workspace_concurrency(tmpdir, 2.0, 6)
 
 
