@@ -18,7 +18,7 @@ def test_SystemMonitor():
     assert all(wb >= 0 for wb in sm.write_bytes)
     assert all(len(q) == 3 for q in sm.quantities.values())
 
-    assert 'cpu' in repr(sm)
+    assert "cpu" in repr(sm)
 
 
 def test_count():
