@@ -9,14 +9,14 @@ from tornado import gen
 
 from distributed import Client, Variable, worker_client, Nanny, wait
 from distributed.metrics import time
-from distributed.utils_test import (gen_cluster, inc, cluster, slow, div)
-from distributed.utils_test import loop # noqa: F401
+from distributed.utils_test import gen_cluster, inc, slow, div
+from distributed.utils_test import client, cluster_fixture, loop  # noqa: F401
 
 
 @gen_cluster(client=True)
 def test_variable(c, s, a, b):
-    x = Variable('x')
-    xx = Variable('x')
+    x = Variable("x")
+    xx = Variable("x")
     assert x.client is c
 
     future = c.submit(inc, 1)
@@ -40,33 +40,31 @@ def test_variable(c, s, a, b):
 
 @gen_cluster(client=True)
 def test_queue_with_data(c, s, a, b):
-    x = Variable('x')
-    xx = Variable('x')
+    x = Variable("x")
+    xx = Variable("x")
     assert x.client is c
 
-    yield x.set((1, 'hello'))
+    yield x.set((1, "hello"))
     data = yield xx.get()
 
-    assert data == (1, 'hello')
+    assert data == (1, "hello")
 
 
-def test_sync(loop):
-    with cluster() as (s, [a, b]):
-        with Client(s['address']) as c:
-            future = c.submit(lambda x: x + 1, 10)
-            x = Variable('x')
-            xx = Variable('x')
-            x.set(future)
-            future2 = xx.get()
+def test_sync(client):
+    future = client.submit(lambda x: x + 1, 10)
+    x = Variable("x")
+    xx = Variable("x")
+    x.set(future)
+    future2 = xx.get()
 
-            assert future2.result() == 11
+    assert future2.result() == 11
 
 
 @gen_cluster()
 def test_hold_futures(s, a, b):
     c1 = yield Client(s.address, asynchronous=True)
     future = c1.submit(lambda x: x + 1, 10)
-    x1 = Variable('x')
+    x1 = Variable("x")
     yield x1.set(future)
     del x1
     yield c1.close()
@@ -74,7 +72,7 @@ def test_hold_futures(s, a, b):
     yield gen.sleep(0.1)
 
     c2 = yield Client(s.address, asynchronous=True)
-    x2 = Variable('x')
+    x2 = Variable("x")
     future2 = yield x2.get()
     result = yield future2
 
@@ -84,7 +82,7 @@ def test_hold_futures(s, a, b):
 
 @gen_cluster(client=True)
 def test_timeout(c, s, a, b):
-    v = Variable('v')
+    v = Variable("v")
 
     start = time()
     with pytest.raises(gen.TimeoutError):
@@ -93,21 +91,19 @@ def test_timeout(c, s, a, b):
     assert 0.1 < stop - start < 2.0
 
 
-def test_timeout_sync(loop):
-    with cluster() as (s, [a, b]):
-        with Client(s['address']) as c:
-            v = Variable('v')
-            start = time()
-            with pytest.raises(gen.TimeoutError):
-                v.get(timeout=0.1)
-            stop = time()
-            assert 0.1 < stop - start < 2.0
+def test_timeout_sync(client):
+    v = Variable("v")
+    start = time()
+    with pytest.raises(gen.TimeoutError):
+        v.get(timeout=0.1)
+    stop = time()
+    assert 0.1 < stop - start < 2.0
 
 
 @gen_cluster(client=True)
 def test_cleanup(c, s, a, b):
-    v = Variable('v')
-    vv = Variable('v')
+    v = Variable("v")
+    vv = Variable("v")
 
     x = c.submit(lambda x: x + 1, 10)
     y = c.submit(lambda x: x + 1, 20)
@@ -127,41 +123,38 @@ def test_cleanup(c, s, a, b):
     assert result == 11
 
 
-def test_pickleable(loop):
-    with cluster() as (s, [a, b]):
-        with Client(s['address']) as c:
-            v = Variable('v')
+def test_pickleable(client):
+    v = Variable("v")
 
-            def f(x):
-                v.set(x + 1)
+    def f(x):
+        v.set(x + 1)
 
-            c.submit(f, 10).result()
-            assert v.get() == 11
+    client.submit(f, 10).result()
+    assert v.get() == 11
 
 
 @gen_cluster(client=True)
 def test_timeout_get(c, s, a, b):
-    v = Variable('v')
+    v = Variable("v")
 
     tornado_future = v.get()
 
-    vv = Variable('v')
+    vv = Variable("v")
     yield vv.set(1)
 
     result = yield tornado_future
     assert result == 1
 
 
-@pytest.mark.skipif(sys.version_info[0] == 2, reason='Multi-client issues')
+@pytest.mark.skipif(sys.version_info[0] == 2, reason="Multi-client issues")
 @slow
-@gen_cluster(client=True, ncores=[('127.0.0.1', 2)] * 5, Worker=Nanny,
-             timeout=None)
+@gen_cluster(client=True, ncores=[("127.0.0.1", 2)] * 5, Worker=Nanny, timeout=None)
 def test_race(c, s, *workers):
     NITERS = 50
 
     def f(i):
         with worker_client() as c:
-            v = Variable('x', client=c)
+            v = Variable("x", client=c)
             for _ in range(NITERS):
                 future = v.get()
                 x = future.result()
@@ -172,7 +165,7 @@ def test_race(c, s, *workers):
             sleep(0.1)  # allow fire-and-forget messages to clear
             return result
 
-    v = Variable('x', client=c)
+    v = Variable("x", client=c)
     x = yield c.scatter(1)
     yield v.set(x)
 
@@ -181,7 +174,7 @@ def test_race(c, s, *workers):
     assert all(r > NITERS * 0.8 for r in results)
 
     start = time()
-    while len(s.wants_what['variable-x']) != 1:
+    while len(s.wants_what["variable-x"]) != 1:
         yield gen.sleep(0.01)
         assert time() - start < 2
 
@@ -189,20 +182,20 @@ def test_race(c, s, *workers):
 @gen_cluster(client=True)
 def test_Future_knows_status_immediately(c, s, a, b):
     x = yield c.scatter(123)
-    v = Variable('x')
+    v = Variable("x")
     yield v.set(x)
 
     c2 = yield Client(s.address, asynchronous=True)
-    v2 = Variable('x', client=c2)
+    v2 = Variable("x", client=c2)
     future = yield v2.get()
-    assert future.status == 'finished'
+    assert future.status == "finished"
 
     x = c.submit(div, 1, 0)
     yield wait(x)
     yield v.set(x)
 
     future2 = yield v2.get()
-    assert future2.status == 'error'
+    assert future2.status == "error"
     with pytest.raises(Exception):
         yield future2
 
@@ -233,16 +226,14 @@ def test_erred_future(c, s, a, b):
     assert isinstance(exc, ZeroDivisionError)
 
 
-def test_future_erred_sync(loop):
-    with cluster() as (s, [a, b]):
-        with Client(s['address']) as c:
-            future = c.submit(div, 1, 0)
-            var = Variable()
-            var.set(future)
+def test_future_erred_sync(client):
+    future = client.submit(div, 1, 0)
+    var = Variable()
+    var.set(future)
 
-            sleep(0.1)
+    sleep(0.1)
 
-            future2 = var.get()
+    future2 = var.get()
 
-            with pytest.raises(ZeroDivisionError):
-                future2.result()
+    with pytest.raises(ZeroDivisionError):
+        future2.result()
