@@ -40,6 +40,7 @@ import toolz
 import tornado
 from tornado import gen
 from tornado.ioloop import IOLoop
+
 try:
     from tornado.ioloop import PollIOLoop
 except ImportError:
@@ -57,17 +58,17 @@ except ImportError:
 logger = _logger = logging.getLogger(__name__)
 
 
-no_default = '__no_default__'
+no_default = "__no_default__"
 
 
 def _initialize_mp_context():
-    if PY3 and not sys.platform.startswith('win') and 'PyPy' not in sys.version:
-        method = dask.config.get('distributed.worker.multiprocessing-method')
+    if PY3 and not sys.platform.startswith("win") and "PyPy" not in sys.version:
+        method = dask.config.get("distributed.worker.multiprocessing-method")
         ctx = multiprocessing.get_context(method)
         # Makes the test suite much faster
-        preload = ['distributed']
-        if 'pkg_resources' in sys.modules:
-            preload.append('pkg_resources')
+        preload = ["distributed"]
+        if "pkg_resources" in sys.modules:
+            preload.append("pkg_resources")
         ctx.set_forkserver_preload(preload)
     else:
         ctx = multiprocessing
@@ -80,7 +81,7 @@ mp_context = _initialize_mp_context()
 
 def funcname(func):
     """Get the name of a function."""
-    while hasattr(func, 'func'):
+    while hasattr(func, "func"):
         func = func.func
     try:
         return func.__name__
@@ -129,29 +130,31 @@ def _get_ip(host, port, family, default):
         return ip
     except EnvironmentError as e:
         # XXX Should first try getaddrinfo() on socket.gethostname() and getfqdn()
-        warnings.warn("Couldn't detect a suitable IP address for "
-                      "reaching %r, defaulting to %r: %s"
-                      % (host, default, e), RuntimeWarning)
+        warnings.warn(
+            "Couldn't detect a suitable IP address for "
+            "reaching %r, defaulting to %r: %s" % (host, default, e),
+            RuntimeWarning,
+        )
         return default
     finally:
         sock.close()
 
 
-def get_ip(host='8.8.8.8', port=80):
+def get_ip(host="8.8.8.8", port=80):
     """
     Get the local IP address through which the *host* is reachable.
 
     *host* defaults to a well-known Internet host (one of Google's public
     DNS servers).
     """
-    return _get_ip(host, port, family=socket.AF_INET, default='127.0.0.1')
+    return _get_ip(host, port, family=socket.AF_INET, default="127.0.0.1")
 
 
-def get_ipv6(host='2001:4860:4860::8888', port=80):
+def get_ipv6(host="2001:4860:4860::8888", port=80):
     """
     The same as get_ip(), but for IPv6.
     """
-    return _get_ip(host, port, family=socket.AF_INET6, default='::1')
+    return _get_ip(host, port, family=socket.AF_INET6, default="::1")
 
 
 def get_ip_interface(ifname):
@@ -163,6 +166,7 @@ def get_ip_interface(ifname):
     associated with it.
     """
     import psutil
+
     for info in psutil.net_if_addrs()[ifname]:
         if info.family == socket.AF_INET:
             return info.address
@@ -213,6 +217,7 @@ def All(args, quiet_exceptions=()):
         try:
             result = yield tasks.next()
         except Exception:
+
             @gen.coroutine
             def quiet():
                 """ Watch unfinished tasks
@@ -226,6 +231,7 @@ def All(args, quiet_exceptions=()):
                         yield task
                     except quiet_exceptions:
                         pass
+
             quiet()
             raise
 
@@ -251,6 +257,7 @@ def Any(args, quiet_exceptions=()):
         try:
             result = yield tasks.next()
         except Exception:
+
             @gen.coroutine
             def quiet():
                 """ Watch unfinished tasks
@@ -264,6 +271,7 @@ def Any(args, quiet_exceptions=()):
                         yield task
                     except quiet_exceptions:
                         pass
+
             quiet()
             raise
 
@@ -277,8 +285,10 @@ def sync(loop, func, *args, **kwargs):
     Run coroutine in loop running in separate thread.
     """
     # Tornado's PollIOLoop doesn't raise when using closed, do it ourselves
-    if PollIOLoop and ((isinstance(loop, PollIOLoop) and getattr(loop, '_closing', False)) or
-            (hasattr(loop, 'asyncio_loop') and loop.asyncio_loop._closed)):
+    if PollIOLoop and (
+        (isinstance(loop, PollIOLoop) and getattr(loop, "_closing", False))
+        or (hasattr(loop, "asyncio_loop") and loop.asyncio_loop._closed)
+    ):
         raise RuntimeError("IOLoop is closed")
     try:
         if loop.asyncio_loop.is_closed():  # tornado 6
@@ -286,7 +296,7 @@ def sync(loop, func, *args, **kwargs):
     except AttributeError:
         pass
 
-    timeout = kwargs.pop('callback_timeout', None)
+    timeout = kwargs.pop("callback_timeout", None)
 
     e = threading.Event()
     main_tid = get_thread_identity()
@@ -339,6 +349,7 @@ class LoopRunner(object):
         If true, the loop is meant to run in the thread this
         object is instantiated from, and will not be started automatically.
     """
+
     # All loops currently associated to loop runners
     _all_loops = weakref.WeakKeyDictionary()
     _lock = threading.Lock()
@@ -376,7 +387,7 @@ class LoopRunner(object):
         assert not self._started
 
         count, real_runner = self._all_loops[self._loop]
-        if (self._asynchronous or real_runner is not None or count > 0):
+        if self._asynchronous or real_runner is not None or count > 0:
             self._all_loops[self._loop] = count + 1, real_runner
             self._started = True
             return
@@ -414,7 +425,9 @@ class LoopRunner(object):
             # Loop already running in other thread (user-launched)
             done_evt.wait(5)
             if not isinstance(start_exc[0], RuntimeError):
-                if not isinstance(start_exc[0], Exception):  # track down infrequent error
+                if not isinstance(
+                    start_exc[0], Exception
+                ):  # track down infrequent error
                     raise TypeError("not an exception", start_exc[0])
                 raise start_exc[0]
             self._all_loops[self._loop] = count + 1, None
@@ -507,7 +520,7 @@ def set_thread_state(**kwargs):
 @contextmanager
 def tmp_text(filename, text):
     fn = os.path.join(tempfile.gettempdir(), filename)
-    with open(fn, 'w') as f:
+    with open(fn, "w") as f:
         f.write(text)
 
     try:
@@ -529,14 +542,15 @@ def is_kernel():
     False
     """
     # http://stackoverflow.com/questions/34091701/determine-if-were-in-an-ipython-notebook-session
-    if 'IPython' not in sys.modules:  # IPython hasn't been imported
+    if "IPython" not in sys.modules:  # IPython hasn't been imported
         return False
     from IPython import get_ipython
+
     # check for `kernel` attribute on the IPython instance
-    return getattr(get_ipython(), 'kernel', None) is not None
+    return getattr(get_ipython(), "kernel", None) is not None
 
 
-hex_pattern = re.compile('[a-f]+')
+hex_pattern = re.compile("[a-f]+")
 
 
 def key_split(s):
@@ -571,25 +585,26 @@ def key_split(s):
     if type(s) is tuple:
         s = s[0]
     try:
-        words = s.split('-')
+        words = s.split("-")
         if not words[0][0].isalpha():
             result = words[0].split(",")[0].strip("'(\"")
         else:
             result = words[0]
         for word in words[1:]:
-            if word.isalpha() and not (len(word) == 8 and
-                                       hex_pattern.match(word) is not None):
-                result += '-' + word
+            if word.isalpha() and not (
+                len(word) == 8 and hex_pattern.match(word) is not None
+            ):
+                result += "-" + word
             else:
                 break
-        if len(result) == 32 and re.match(r'[a-f0-9]{32}', result):
-            return 'data'
+        if len(result) == 32 and re.match(r"[a-f0-9]{32}", result):
+            return "data"
         else:
-            if result[0] == '<':
-                result = result.strip('<>').split()[0].split('.')[-1]
+            if result[0] == "<":
+                result = result.strip("<>").split()[0].split(".")[-1]
             return result
     except Exception:
-        return 'Other'
+        return "Other"
 
 
 try:
@@ -601,6 +616,7 @@ else:
     key_split = lru_cache(100000)(key_split)
 
 if PY3:
+
     def key_split_group(x):
         """A more fine-grained version of key_split
 
@@ -631,19 +647,22 @@ if PY3:
         if typ is tuple:
             return x[0]
         elif typ is str:
-            if x[0] == '(':
-                return x.split(',', 1)[0].strip('()"\'')
-            elif len(x) == 32 and re.match(r'[a-f0-9]{32}', x):
-                return 'data'
-            elif x[0] == '<':
-                return x.strip('<>').split()[0].split('.')[-1]
+            if x[0] == "(":
+                return x.split(",", 1)[0].strip("()\"'")
+            elif len(x) == 32 and re.match(r"[a-f0-9]{32}", x):
+                return "data"
+            elif x[0] == "<":
+                return x.strip("<>").split()[0].split(".")[-1]
             else:
                 return x
         elif typ is bytes:
             return key_split_group(x.decode())
         else:
-            return 'Other'
+            return "Other"
+
+
 else:
+
     def key_split_group(x):
         """A more fine-grained version of key_split
 
@@ -674,21 +693,22 @@ else:
         if typ is tuple:
             return x[0]
         elif typ is str or typ is unicode:
-            if x[0] == '(':
-                return x.split(',', 1)[0].strip('()"\'')
-            elif len(x) == 32 and re.match(r'[a-f0-9]{32}', x):
-                return 'data'
-            elif x[0] == '<':
-                return x.strip('<>').split()[0].split('.')[-1]
+            if x[0] == "(":
+                return x.split(",", 1)[0].strip("()\"'")
+            elif len(x) == 32 and re.match(r"[a-f0-9]{32}", x):
+                return "data"
+            elif x[0] == "<":
+                return x.strip("<>").split()[0].split(".")[-1]
             else:
                 return x
         else:
-            return 'Other'
+            return "Other"
 
 
 @contextmanager
 def log_errors(pdb=False):
     from .comm import CommClosedError
+
     try:
         yield
     except (CommClosedError, gen.Return):
@@ -700,14 +720,14 @@ def log_errors(pdb=False):
             pass
         if pdb:
             import pdb
+
             pdb.set_trace()
         raise
 
 
-def silence_logging(level, root='distributed'):
+def silence_logging(level, root="distributed"):
     """
-    Force all existing loggers below *root* to the given level at least
-    (or keep the existing level if less verbose).
+    Change all StreamHandlers for the given logger to the given level
     """
     if isinstance(level, str):
         level = getattr(logging, level.upper())
@@ -737,9 +757,9 @@ def ensure_ip(hostname):
     families = [socket.AF_INET, socket.AF_INET6]
     for fam in families:
         try:
-            results = socket.getaddrinfo(hostname,
-                                         1234,  # dummy port number
-                                         fam, socket.SOCK_STREAM)
+            results = socket.getaddrinfo(
+                hostname, 1234, fam, socket.SOCK_STREAM  # dummy port number
+            )
         except socket.gaierror as e:
             exc = e
         else:
@@ -753,12 +773,15 @@ tblib.pickling_support.install()
 
 def get_traceback():
     exc_type, exc_value, exc_traceback = sys.exc_info()
-    bad = [os.path.join('distributed', 'worker'),
-           os.path.join('distributed', 'scheduler'),
-           os.path.join('tornado', 'gen.py'),
-           os.path.join('concurrent', 'futures')]
-    while exc_traceback and any(b in exc_traceback.tb_frame.f_code.co_filename
-                                for b in bad):
+    bad = [
+        os.path.join("distributed", "worker"),
+        os.path.join("distributed", "scheduler"),
+        os.path.join("tornado", "gen.py"),
+        os.path.join("concurrent", "futures"),
+    ]
+    while exc_traceback and any(
+        b in exc_traceback.tb_frame.f_code.co_filename for b in bad
+    ):
         exc_traceback = exc_traceback.tb_next
     return exc_traceback
 
@@ -767,25 +790,24 @@ def truncate_exception(e, n=10000):
     """ Truncate exception to be about a certain length """
     if len(str(e)) > n:
         try:
-            return type(e)("Long error message",
-                           str(e)[:n])
+            return type(e)("Long error message", str(e)[:n])
         except Exception:
-            return Exception("Long error message",
-                             type(e),
-                             str(e)[:n])
+            return Exception("Long error message", type(e), str(e)[:n])
     else:
         return e
 
 
 if sys.version_info >= (3,):
     # (re-)raising StopIteration is deprecated in 3.6+
-    exec("""def queue_to_iterator(q):
+    exec(
+        """def queue_to_iterator(q):
         while True:
             result = q.get()
             if isinstance(result, StopIteration):
                 return result.value
             yield result
-        """)
+        """
+    )
 else:
     # Returning non-None from generator is a syntax error in 2.x
     def queue_to_iterator(q):
@@ -836,15 +858,18 @@ def validate_key(k):
     """
     typ = type(k)
     if typ is not unicode and typ is not bytes:
-        raise TypeError("Unexpected key type %s (value: %r)"
-                        % (typ, k))
+        raise TypeError("Unexpected key type %s (value: %r)" % (typ, k))
 
 
 def _maybe_complex(task):
     """ Possibly contains a nested task """
-    return (istask(task) or
-            type(task) is list and any(map(_maybe_complex, task)) or
-            type(task) is dict and any(map(_maybe_complex, task.values())))
+    return (
+        istask(task)
+        or type(task) is list
+        and any(map(_maybe_complex, task))
+        or type(task) is dict
+        and any(map(_maybe_complex, task.values()))
+    )
 
 
 def convert(task, dsk, extra_values):
@@ -884,7 +909,7 @@ def seek_delimiter(file, delimiter, blocksize):
     if file.tell() == 0:
         return
 
-    last = b''
+    last = b""
     while True:
         current = file.read(blocksize)
         if not current:
@@ -896,7 +921,7 @@ def seek_delimiter(file, delimiter, blocksize):
             return
         except ValueError:
             pass
-        last = full[-len(delimiter):]
+        last = full[-len(delimiter) :]
 
 
 def read_block(f, offset, length, delimiter=None):
@@ -935,12 +960,12 @@ def read_block(f, offset, length, delimiter=None):
     """
     if delimiter:
         f.seek(offset)
-        seek_delimiter(f, delimiter, 2**16)
+        seek_delimiter(f, delimiter, 2 ** 16)
         start = f.tell()
         length -= start - offset
 
         f.seek(start + length)
-        seek_delimiter(f, delimiter, 2**16)
+        seek_delimiter(f, delimiter, 2 ** 16)
         end = f.tell()
 
         offset = start
@@ -952,8 +977,8 @@ def read_block(f, offset, length, delimiter=None):
 
 
 @contextmanager
-def tmpfile(extension=''):
-    extension = '.' + extension.lstrip('.')
+def tmpfile(extension=""):
+    extension = "." + extension.lstrip(".")
     handle, filename = tempfile.mkstemp(extension)
     os.close(handle)
     os.remove(filename)
@@ -984,10 +1009,9 @@ def ensure_bytes(s):
         return s.tobytes()
     if isinstance(s, bytearray) or PY2 and isinstance(s, buffer):  # noqa: F821
         return bytes(s)
-    if hasattr(s, 'encode'):
+    if hasattr(s, "encode"):
         return s.encode()
-    raise TypeError(
-        "Object %s is neither a bytes object nor has an encode method" % s)
+    raise TypeError("Object %s is neither a bytes object nor has an encode method" % s)
 
 
 def divide_n_among_bins(n, bins):
@@ -1020,9 +1044,11 @@ def mean(seq):
 
 
 if hasattr(sys, "is_finalizing"):
+
     def shutting_down(is_finalizing=sys.is_finalizing):
         return is_finalizing()
 
+
 else:
     _shutting_down = [False]
 
@@ -1043,7 +1069,7 @@ shutting_down.__doc__ = """
     """
 
 
-def open_port(host=''):
+def open_port(host=""):
     """ Return a probably-open port
 
     There is a chance that this port will be taken by the operating system soon
@@ -1065,23 +1091,24 @@ def import_file(path):
     names_to_import = []
     tmp_python_path = None
 
-    if ext in ('.py',):  # , '.pyc'):
+    if ext in (".py",):  # , '.pyc'):
         if directory not in sys.path:
             tmp_python_path = directory
         names_to_import.append(name)
-    if ext == '.py':  # Ensure that no pyc file will be reused
+    if ext == ".py":  # Ensure that no pyc file will be reused
         cache_file = cache_from_source(path)
         with ignoring(OSError):
             os.remove(cache_file)
-    if ext in ('.egg', '.zip', '.pyz'):
+    if ext in (".egg", ".zip", ".pyz"):
         if path not in sys.path:
             sys.path.insert(0, path)
-        if ext == '.egg':
+        if ext == ".egg":
             import pkg_resources
+
             pkgs = pkg_resources.find_distributions(path)
             for pkg in pkgs:
                 names_to_import.append(pkg.project_name)
-        elif ext in ('.zip', '.pyz'):
+        elif ext in (".zip", ".pyz"):
             names_to_import.append(name)
 
     loaded = []
@@ -1111,7 +1138,8 @@ class itemgetter(object):
     >>> get_1(data)
     1
     """
-    __slots__ = ('index',)
+
+    __slots__ = ("index",)
 
     def __init__(self, index):
         self.index = index
@@ -1140,35 +1168,35 @@ def format_bytes(n):
     '1.23 PB'
     """
     if n > 1e15:
-        return '%0.2f PB' % (n / 1e15)
+        return "%0.2f PB" % (n / 1e15)
     if n > 1e12:
-        return '%0.2f TB' % (n / 1e12)
+        return "%0.2f TB" % (n / 1e12)
     if n > 1e9:
-        return '%0.2f GB' % (n / 1e9)
+        return "%0.2f GB" % (n / 1e9)
     if n > 1e6:
-        return '%0.2f MB' % (n / 1e6)
+        return "%0.2f MB" % (n / 1e6)
     if n > 1e3:
-        return '%0.2f kB' % (n / 1000)
-    return '%d B' % n
+        return "%0.2f kB" % (n / 1000)
+    return "%d B" % n
 
 
 byte_sizes = {
-        'kB': 10**3,
-        'MB': 10**6,
-        'GB': 10**9,
-        'TB': 10**12,
-        'PB': 10**15,
-        'KiB': 2**10,
-        'MiB': 2**20,
-        'GiB': 2**30,
-        'TiB': 2**40,
-        'PiB': 2**50,
-        'B': 1,
-        '': 1,
+    "kB": 10 ** 3,
+    "MB": 10 ** 6,
+    "GB": 10 ** 9,
+    "TB": 10 ** 12,
+    "PB": 10 ** 15,
+    "KiB": 2 ** 10,
+    "MiB": 2 ** 20,
+    "GiB": 2 ** 30,
+    "TiB": 2 ** 40,
+    "PiB": 2 ** 50,
+    "B": 1,
+    "": 1,
 }
 byte_sizes = {k.lower(): v for k, v in byte_sizes.items()}
-byte_sizes.update({k[0]: v for k, v in byte_sizes.items() if k and 'i' not in k})
-byte_sizes.update({k[:-1]: v for k, v in byte_sizes.items() if k and 'i' in k})
+byte_sizes.update({k[0]: v for k, v in byte_sizes.items() if k and "i" not in k})
+byte_sizes.update({k[:-1]: v for k, v in byte_sizes.items() if k and "i" in k})
 
 
 def parse_bytes(s):
@@ -1193,9 +1221,9 @@ def parse_bytes(s):
     >>> parse_bytes('MB')
     1000000
     """
-    s = s.replace(' ', '')
+    s = s.replace(" ", "")
     if not s[0].isdigit():
-        s = '1' + s
+        s = "1" + s
 
     for i in range(len(s) - 1, -1, -1):
         if not s[i].isalpha():
@@ -1214,30 +1242,30 @@ def parse_bytes(s):
 
 
 timedelta_sizes = {
-        's': 1,
-        'ms': 1e-3,
-        'us': 1e-6,
-        'ns': 1e-9,
-        'm': 60,
-        'h': 3600,
-        'd': 3600 * 24,
+    "s": 1,
+    "ms": 1e-3,
+    "us": 1e-6,
+    "ns": 1e-9,
+    "m": 60,
+    "h": 3600,
+    "d": 3600 * 24,
 }
 
 tds2 = {
-        'second': 1,
-        'minute': 60,
-        'hour': 60 * 60,
-        'day': 60 * 60 * 24,
-        'millisecond': 1e-3,
-        'microsecond': 1e-6,
-        'nanosecond': 1e-9,
+    "second": 1,
+    "minute": 60,
+    "hour": 60 * 60,
+    "day": 60 * 60 * 24,
+    "millisecond": 1e-3,
+    "microsecond": 1e-6,
+    "nanosecond": 1e-9,
 }
-tds2.update({k + 's': v for k, v in tds2.items()})
+tds2.update({k + "s": v for k, v in tds2.items()})
 timedelta_sizes.update(tds2)
 timedelta_sizes.update({k.upper(): v for k, v in timedelta_sizes.items()})
 
 
-def parse_timedelta(s, default='seconds'):
+def parse_timedelta(s, default="seconds"):
     """ Parse timedelta string to number of seconds
 
     Examples
@@ -1255,9 +1283,9 @@ def parse_timedelta(s, default='seconds'):
         return s.total_seconds()
     if isinstance(s, Number):
         s = str(s)
-    s = s.replace(' ', '')
+    s = s.replace(" ", "")
     if not s[0].isdigit():
-        s = '1' + s
+        s = "1" + s
 
     for i in range(len(s) - 1, -1, -1):
         if not s[i].isalpha():
@@ -1290,16 +1318,16 @@ def asciitable(columns, rows):
     """
     rows = [tuple(str(i) for i in r) for r in rows]
     columns = tuple(str(i) for i in columns)
-    widths = tuple(max(max(map(len, x)), len(c))
-                   for x, c in zip(zip(*rows), columns))
-    row_template = ('|' + (' %%-%ds |' * len(columns))) % widths
+    widths = tuple(max(max(map(len, x)), len(c)) for x, c in zip(zip(*rows), columns))
+    row_template = ("|" + (" %%-%ds |" * len(columns))) % widths
     header = row_template % tuple(columns)
-    bar = '+%s+' % '+'.join('-' * (w + 2) for w in widths)
-    data = '\n'.join(row_template % r for r in rows)
-    return '\n'.join([bar, header, bar, data, bar])
+    bar = "+%s+" % "+".join("-" * (w + 2) for w in widths)
+    data = "\n".join(row_template % r for r in rows)
+    return "\n".join([bar, header, bar, data, bar])
 
 
 if PY2:
+
     def nbytes(frame, _bytes_like=(bytes, bytearray, buffer)):  # noqa: F821
         """ Number of bytes of a frame or memoryview """
         if isinstance(frame, _bytes_like):
@@ -1308,11 +1336,13 @@ if PY2:
             if frame.shape is None:
                 return frame.itemsize
             else:
-                return functools.reduce(operator.mul, frame.shape,
-                                        frame.itemsize)
+                return functools.reduce(operator.mul, frame.shape, frame.itemsize)
         else:
             return frame.nbytes
+
+
 else:
+
     def nbytes(frame, _bytes_like=(bytes, bytearray)):
         """ Number of bytes of a frame or memoryview """
         if isinstance(frame, _bytes_like):
@@ -1341,7 +1371,7 @@ def time_warn(duration, text):
     yield
     end = time()
     if end - start > duration:
-        print('TIME WARNING', text, end - start)
+        print("TIME WARNING", text, end - start)
 
 
 def json_load_robust(fn, load=json.load):
@@ -1372,18 +1402,19 @@ def format_time(n):
     '123.46 s'
     """
     if n >= 1:
-        return '%.2f s' % n
+        return "%.2f s" % n
     if n >= 1e-3:
-        return '%.2f ms' % (n * 1e3)
-    return '%.2f us' % (n * 1e6)
+        return "%.2f ms" % (n * 1e3)
+    return "%.2f us" % (n * 1e6)
 
 
 class DequeHandler(logging.Handler):
     """ A logging.Handler that records records into a deque """
+
     _instances = weakref.WeakSet()
 
     def __init__(self, *args, **kwargs):
-        n = kwargs.pop('n', 10000)
+        n = kwargs.pop("n", 10000)
         self.deque = deque(maxlen=n)
         super(DequeHandler, self).__init__(*args, **kwargs)
         self._instances.add(self)
@@ -1417,22 +1448,25 @@ def reset_logger_locks():
 
 
 # Only bother if asyncio has been loaded by Tornado
-if 'asyncio' in sys.modules and tornado.version_info[0] >= 5:
+if "asyncio" in sys.modules and tornado.version_info[0] >= 5:
 
     jupyter_event_loop_initialized = False
 
-    if 'notebook' in sys.modules:
+    if "notebook" in sys.modules:
         import traitlets
         from notebook.notebookapp import NotebookApp
-        jupyter_event_loop_initialized = (
-            traitlets.config.Application.initialized() and
-            isinstance(traitlets.config.Application.instance(), NotebookApp)
+
+        jupyter_event_loop_initialized = traitlets.config.Application.initialized() and isinstance(
+            traitlets.config.Application.instance(), NotebookApp
         )
 
     if not jupyter_event_loop_initialized:
         import asyncio
         import tornado.platform.asyncio
-        asyncio.set_event_loop_policy(tornado.platform.asyncio.AnyThreadEventLoopPolicy())
+
+        asyncio.set_event_loop_policy(
+            tornado.platform.asyncio.AnyThreadEventLoopPolicy()
+        )
 
 
 def has_keyword(func, keyword):
@@ -1451,9 +1485,26 @@ if lru_cache:
 
 # from bokeh.palettes import viridis
 # palette = viridis(18)
-palette = ['#440154', '#471669', '#472A79', '#433C84', '#3C4D8A', '#355D8C',
-           '#2E6C8E', '#287A8E', '#23898D', '#1E978A', '#20A585', '#2EB27C',
-           '#45BF6F', '#64CB5D', '#88D547', '#AFDC2E', '#D7E219', '#FDE724']
+palette = [
+    "#440154",
+    "#471669",
+    "#472A79",
+    "#433C84",
+    "#3C4D8A",
+    "#355D8C",
+    "#2E6C8E",
+    "#287A8E",
+    "#23898D",
+    "#1E978A",
+    "#20A585",
+    "#2EB27C",
+    "#45BF6F",
+    "#64CB5D",
+    "#88D547",
+    "#AFDC2E",
+    "#D7E219",
+    "#FDE724",
+]
 
 
 @toolz.memoize
@@ -1478,3 +1529,18 @@ def warn_on_duration(duration, msg):
     stop = time()
     if stop - start > parse_timedelta(duration):
         warnings.warn(msg, stacklevel=2)
+
+
+def typename(typ):
+    """ Return name of type
+
+    Examples
+    --------
+    >>> from distributed import Scheduler
+    >>> typename(Scheduler)
+    'distributed.scheduler.Scheduler'
+    """
+    try:
+        return typ.__module__ + "." + typ.__name__
+    except AttributeError:
+        return str(typ)
